# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: infragraph.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'infragraph.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10infragraph.proto\x12\ninfragraph\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xf4\x01\n\x0eInfrastructure\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01\x88\x01\x01\x12#\n\x07\x64\x65vices\x18\x03 \x03(\x0b\x32\x12.infragraph.Device\x12\x1f\n\x05links\x18\x04 \x03(\x0b\x32\x10.infragraph.Link\x12\'\n\tinstances\x18\x05 \x03(\x0b\x32\x14.infragraph.Instance\x12-\n\x05\x65\x64ges\x18\x06 \x03(\x0b\x32\x1e.infragraph.InfrastructureEdgeB\x07\n\x05_nameB\x0e\n\x0c_description\"\xc1\x01\n\x06\x44\x65vice\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01\x88\x01\x01\x12)\n\ncomponents\x18\x03 \x03(\x0b\x32\x15.infragraph.Component\x12\x1f\n\x05links\x18\x04 \x03(\x0b\x32\x10.infragraph.Link\x12%\n\x05\x65\x64ges\x18\x05 \x03(\x0b\x32\x16.infragraph.DeviceEdgeB\x07\n\x05_nameB\x0e\n\x0c_description\"-\n\x0f\x43omponentCustom\x12\x11\n\x04type\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_type\"\x11\n\x0f\x43omponentDevice\"\x0e\n\x0c\x43omponentCpu\"\x0e\n\x0c\x43omponentNpu\"\x0e\n\x0c\x43omponentNic\"\x11\n\x0f\x43omponentMemory\"\x0f\n\rComponentPort\"\x11\n\x0f\x43omponentSwitch\"\xfc\x04\n\tComponent\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x36\n\x06\x63hoice\x18\x04 \x01(\x0e\x32!.infragraph.Component.Choice.EnumH\x03\x88\x01\x01\x12+\n\x06\x63ustom\x18\n \x01(\x0b\x32\x1b.infragraph.ComponentCustom\x12+\n\x06\x64\x65vice\x18\x0b \x01(\x0b\x32\x1b.infragraph.ComponentDevice\x12%\n\x03\x63pu\x18\x0c \x01(\x0b\x32\x18.infragraph.ComponentCpu\x12%\n\x03npu\x18\r \x01(\x0b\x32\x18.infragraph.ComponentNpu\x12%\n\x03nic\x18\x0e \x01(\x0b\x32\x18.infragraph.ComponentNic\x12+\n\x06memory\x18\x0f \x01(\x0b\x32\x1b.infragraph.ComponentMemory\x12\'\n\x04port\x18\x10 \x01(\x0b\x32\x19.infragraph.ComponentPort\x12+\n\x06switch\x18\x11 \x01(\x0b\x32\x1b.infragraph.ComponentSwitch\x1av\n\x06\x43hoice\"l\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\n\n\x06\x64\x65vice\x10\x02\x12\x07\n\x03\x63pu\x10\x03\x12\x07\n\x03npu\x10\x04\x12\x07\n\x03nic\x10\x05\x12\n\n\x06memory\x10\x06\x12\x08\n\x04port\x10\x07\x12\n\n\x06switch\x10\x08\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\x08\n\x06_countB\t\n\x07_choice\"\x94\x03\n\x15LinkPhysicalBandwidth\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.infragraph.LinkPhysicalBandwidth.Choice.EnumH\x00\x88\x01\x01\x12 \n\x13gigabits_per_second\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12!\n\x14gigabytes_per_second\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12%\n\x18gigatransfers_per_second\x18\x04 \x01(\x02H\x03\x88\x01\x01\x1ar\n\x06\x43hoice\"h\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13gigabits_per_second\x10\x01\x12\x18\n\x14gigabytes_per_second\x10\x02\x12\x1c\n\x18gigatransfers_per_second\x10\x03\x42\t\n\x07_choiceB\x16\n\x14_gigabits_per_secondB\x17\n\x15_gigabytes_per_secondB\x1b\n\x19_gigatransfers_per_second\"\xe5\x01\n\x13LinkPhysicalLatency\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.infragraph.LinkPhysicalLatency.Choice.EnumH\x00\x88\x01\x01\x12\x0f\n\x02ms\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x0f\n\x02us\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x0f\n\x02ns\x18\x04 \x01(\x02H\x03\x88\x01\x01\x1a\x39\n\x06\x43hoice\"/\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02ms\x10\x01\x12\x06\n\x02us\x10\x02\x12\x06\n\x02ns\x10\x03\x42\t\n\x07_choiceB\x05\n\x03_msB\x05\n\x03_usB\x05\n\x03_ns\"v\n\x0cLinkPhysical\x12\x34\n\tbandwidth\x18\x01 \x01(\x0b\x32!.infragraph.LinkPhysicalBandwidth\x12\x30\n\x07latency\x18\x02 \x01(\x0b\x32\x1f.infragraph.LinkPhysicalLatency\"x\n\x04Link\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01\x88\x01\x01\x12*\n\x08physical\x18\x03 \x01(\x0b\x32\x18.infragraph.LinkPhysicalB\x07\n\x05_nameB\x0e\n\x0c_description\"V\n\x0e\x44\x65viceEndpoint\x12\x13\n\x06\x64\x65vice\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tcomponent\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_deviceB\x0c\n\n_component\"b\n\x16InfrastructureEndpoint\x12\x15\n\x08instance\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tcomponent\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_instanceB\x0c\n\n_component\"\xa7\x02\n\x12InfrastructureEdge\x12/\n\x03\x65p1\x18\x01 \x01(\x0b\x32\".infragraph.InfrastructureEndpoint\x12/\n\x03\x65p2\x18\x02 \x01(\x0b\x32\".infragraph.InfrastructureEndpoint\x12?\n\x06scheme\x18\x03 \x01(\x0e\x32*.infragraph.InfrastructureEdge.Scheme.EnumH\x00\x88\x01\x01\x12\x11\n\x04link\x18\x04 \x01(\tH\x01\x88\x01\x01\x1aG\n\x06Scheme\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07one2one\x10\x01\x12\r\n\tmany2many\x10\x02\x12\x08\n\x04ring\x10\x03\x42\t\n\x07_schemeB\x07\n\x05_link\"\x87\x02\n\nDeviceEdge\x12\'\n\x03\x65p1\x18\x01 \x01(\x0b\x32\x1a.infragraph.DeviceEndpoint\x12\'\n\x03\x65p2\x18\x02 \x01(\x0b\x32\x1a.infragraph.DeviceEndpoint\x12\x37\n\x06scheme\x18\x03 \x01(\x0e\x32\".infragraph.DeviceEdge.Scheme.EnumH\x00\x88\x01\x01\x12\x11\n\x04link\x18\x04 \x01(\tH\x01\x88\x01\x01\x1aG\n\x06Scheme\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07one2one\x10\x01\x12\r\n\tmany2many\x10\x02\x12\x08\n\x04ring\x10\x03\x42\t\n\x07_schemeB\x07\n\x05_link\"\x8e\x01\n\x08Instance\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06\x64\x65vice\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x04 \x01(\x05H\x03\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\t\n\x07_deviceB\x08\n\x06_count\"\xab\x01\n\x05\x45rror\x12\x11\n\x04\x63ode\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12.\n\x04kind\x18\x02 \x01(\x0e\x32\x1b.infragraph.Error.Kind.EnumH\x01\x88\x01\x01\x12\x0e\n\x06\x65rrors\x18\x03 \x03(\t\x1a=\n\x04Kind\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nvalidation\x10\x01\x12\x0c\n\x08internal\x10\x02\x42\x07\n\x05_codeB\x07\n\x05_kind\"\x1b\n\x07Warning\x12\x10\n\x08warnings\x18\x01 \x03(\t\"\x85\x01\n\x0cGraphRequest\x12\x39\n\x06\x66ormat\x18\x01 \x01(\x0e\x32$.infragraph.GraphRequest.Format.EnumH\x00\x88\x01\x01\x1a/\n\x06\x46ormat\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08networkx\x10\x01\x42\t\n\x07_format\"\xa9\x01\n\x0cGraphContent\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.infragraph.GraphContent.Choice.EnumH\x00\x88\x01\x01\x12\x15\n\x08networkx\x18\x02 \x01(\tH\x01\x88\x01\x01\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08networkx\x10\x01\x42\t\n\x07_choiceB\x0b\n\t_networkx\"p\n\x0e\x41nnotationNode\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tattribute\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_attributeB\x08\n\x06_value\"\x88\x01\n\x0e\x41nnotationEdge\x12\x10\n\x03\x65p1\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03\x65p2\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tattribute\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05value\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x06\n\x04_ep1B\x06\n\x04_ep2B\x0c\n\n_attributeB\x08\n\x06_value\"\xe9\x01\n\x0f\x41nnotateRequest\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.infragraph.AnnotateRequest.Choice.EnumH\x00\x88\x01\x01\x12)\n\x05nodes\x18\x02 \x03(\x0b\x32\x1a.infragraph.AnnotationNode\x12)\n\x05\x65\x64ges\x18\x03 \x03(\x0b\x32\x1a.infragraph.AnnotationEdge\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05nodes\x10\x01\x12\t\n\x05\x65\x64ges\x10\x02\x42\t\n\x07_choice\"E\n\tNameValue\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\"V\n\x11QueryResponseItem\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12)\n\nattributes\x18\x02 \x03(\x0b\x32\x15.infragraph.NameValueB\x05\n\x03_id\"B\n\x15QueryShortestPathItem\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\r\n\x05nodes\x18\x02 \x03(\tB\x07\n\x05_name\"\xab\x02\n\x14QueryResponseContent\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.infragraph.QueryResponseContent.Choice.EnumH\x00\x88\x01\x01\x12\x33\n\x0cnode_matches\x18\x02 \x03(\x0b\x32\x1d.infragraph.QueryResponseItem\x12@\n\x15shortest_path_matches\x18\x03 \x03(\x0b\x32!.infragraph.QueryShortestPathItem\x1aN\n\x06\x43hoice\"D\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cnode_matches\x10\x01\x12\x19\n\x15shortest_path_matches\x10\x02\x42\t\n\x07_choice\"\xd6\x02\n\x0eQueryAttribute\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12?\n\x08operator\x18\x02 \x01(\x0e\x32(.infragraph.QueryAttribute.Operator.EnumH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x39\n\x05logic\x18\x04 \x01(\x0e\x32%.infragraph.QueryAttribute.Logic.EnumH\x03\x88\x01\x01\x1a\x44\n\x08Operator\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02\x65q\x10\x01\x12\t\n\x05regex\x10\x02\x12\x0c\n\x08\x63ontains\x10\x03\x1a\x31\n\x05Logic\"(\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61nd\x10\x01\x12\x06\n\x02or\x10\x02\x42\x07\n\x05_nameB\x0b\n\t_operatorB\x08\n\x06_valueB\x08\n\x06_logic\"\xb1\x02\n\x0bQueryNodeId\x12<\n\x08operator\x18\x01 \x01(\x0e\x32%.infragraph.QueryNodeId.Operator.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x36\n\x05logic\x18\x03 \x01(\x0e\x32\".infragraph.QueryNodeId.Logic.EnumH\x02\x88\x01\x01\x1a\x44\n\x08Operator\"8\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02\x65q\x10\x01\x12\t\n\x05regex\x10\x02\x12\x0c\n\x08\x63ontains\x10\x03\x1a\x31\n\x05Logic\"(\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61nd\x10\x01\x12\x06\n\x02or\x10\x02\x42\x0b\n\t_operatorB\x08\n\x06_valueB\x08\n\x06_logic\"\xa0\x02\n\x0fQueryNodeFilter\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12<\n\x06\x63hoice\x18\x02 \x01(\x0e\x32\'.infragraph.QueryNodeFilter.Choice.EnumH\x01\x88\x01\x01\x12\x34\n\x10\x61ttribute_filter\x18\x03 \x01(\x0b\x32\x1a.infragraph.QueryAttribute\x12*\n\tid_filter\x18\x04 \x01(\x0b\x32\x17.infragraph.QueryNodeId\x1a\x46\n\x06\x43hoice\"<\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10\x61ttribute_filter\x10\x01\x12\r\n\tid_filter\x10\x02\x42\x07\n\x05_nameB\t\n\x07_choice\"\x7f\n\x17QueryShortestPathFilter\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06source\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0b\x64\x65stination\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_sourceB\x0e\n\x0c_destination\"\x9b\x02\n\x0cQueryRequest\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.infragraph.QueryRequest.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x0cnode_filters\x18\x02 \x03(\x0b\x32\x1b.infragraph.QueryNodeFilter\x12\x42\n\x15shortest_path_filters\x18\x03 \x03(\x0b\x32#.infragraph.QueryShortestPathFilter\x1aN\n\x06\x43hoice\"D\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cnode_filters\x10\x01\x12\x19\n\x15shortest_path_filters\x10\x02\x42\t\n\x07_choice\"\x91\x01\n\x07Version\x12\x1d\n\x10\x61pi_spec_version\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bsdk_version\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0b\x61pp_version\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x13\n\x11_api_spec_versionB\x0e\n\x0c_sdk_versionB\x0e\n\x0c_app_version\"/\n\x07Success\x12$\n\x07warning\x18\x01 \x01(\x0b\x32\x13.infragraph.Warning\"+\n\x07\x46\x61ilure\x12 \n\x05\x65rror\x18\x01 \x01(\x0b\x32\x11.infragraph.Error\"@\n\rGraphResponse\x12/\n\rgraph_content\x18\x01 \x01(\x0b\x32\x18.infragraph.GraphContent\"Q\n\rQueryResponse\x12@\n\x16query_response_content\x18\x01 \x01(\x0b\x32 .infragraph.QueryResponseContent\")\n\x04\x44\x61ta\x12\x12\n\nchunk_size\x18\x01 \x01(\x04\x12\r\n\x05\x64\x61tum\x18\x02 \x01(\x0c\"E\n\x0fSetGraphRequest\x12\x32\n\x0einfrastructure\x18\x01 \x01(\x0b\x32\x1a.infragraph.Infrastructure\"8\n\x10SetGraphResponse\x12$\n\x07warning\x18\x01 \x01(\x0b\x32\x13.infragraph.Warning\"B\n\x0fGetGraphRequest\x12/\n\rgraph_request\x18\x01 \x01(\x0b\x32\x18.infragraph.GraphRequest\"C\n\x10GetGraphResponse\x12/\n\rgraph_content\x18\x01 \x01(\x0b\x32\x18.infragraph.GraphContent\"D\n\x11QueryGraphRequest\x12/\n\rquery_request\x18\x01 \x01(\x0b\x32\x18.infragraph.QueryRequest\"V\n\x12QueryGraphResponse\x12@\n\x16query_response_content\x18\x01 \x01(\x0b\x32 .infragraph.QueryResponseContent\"M\n\x14\x41nnotateGraphRequest\x12\x35\n\x10\x61nnotate_request\x18\x01 \x01(\x0b\x32\x1b.infragraph.AnnotateRequest\"=\n\x15\x41nnotateGraphResponse\x12$\n\x07warning\x18\x01 \x01(\x0b\x32\x13.infragraph.Warning\":\n\x12GetVersionResponse\x12$\n\x07version\x18\x01 \x01(\x0b\x32\x13.infragraph.Version2\x9e\x05\n\x07Openapi\x12\x45\n\x08SetGraph\x12\x1b.infragraph.SetGraphRequest\x1a\x1c.infragraph.SetGraphResponse\x12\x42\n\x0estreamSetGraph\x12\x10.infragraph.Data\x1a\x1c.infragraph.SetGraphResponse(\x01\x12\x45\n\x08GetGraph\x12\x1b.infragraph.GetGraphRequest\x1a\x1c.infragraph.GetGraphResponse\x12\x42\n\x0estreamGetGraph\x12\x10.infragraph.Data\x1a\x1c.infragraph.GetGraphResponse(\x01\x12K\n\nQueryGraph\x12\x1d.infragraph.QueryGraphRequest\x1a\x1e.infragraph.QueryGraphResponse\x12\x46\n\x10streamQueryGraph\x12\x10.infragraph.Data\x1a\x1e.infragraph.QueryGraphResponse(\x01\x12T\n\rAnnotateGraph\x12 .infragraph.AnnotateGraphRequest\x1a!.infragraph.AnnotateGraphResponse\x12L\n\x13streamAnnotateGraph\x12\x10.infragraph.Data\x1a!.infragraph.AnnotateGraphResponse(\x01\x12\x44\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a\x1e.infragraph.GetVersionResponseB\x19Z\x17./infragraph;infragraphb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'infragraph_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\027./infragraph;infragraph'
  _globals['_INFRASTRUCTURE']._serialized_start=96
  _globals['_INFRASTRUCTURE']._serialized_end=340
  _globals['_DEVICE']._serialized_start=343
  _globals['_DEVICE']._serialized_end=536
  _globals['_COMPONENTCUSTOM']._serialized_start=538
  _globals['_COMPONENTCUSTOM']._serialized_end=583
  _globals['_COMPONENTDEVICE']._serialized_start=585
  _globals['_COMPONENTDEVICE']._serialized_end=602
  _globals['_COMPONENTCPU']._serialized_start=604
  _globals['_COMPONENTCPU']._serialized_end=618
  _globals['_COMPONENTNPU']._serialized_start=620
  _globals['_COMPONENTNPU']._serialized_end=634
  _globals['_COMPONENTNIC']._serialized_start=636
  _globals['_COMPONENTNIC']._serialized_end=650
  _globals['_COMPONENTMEMORY']._serialized_start=652
  _globals['_COMPONENTMEMORY']._serialized_end=669
  _globals['_COMPONENTPORT']._serialized_start=671
  _globals['_COMPONENTPORT']._serialized_end=686
  _globals['_COMPONENTSWITCH']._serialized_start=688
  _globals['_COMPONENTSWITCH']._serialized_end=705
  _globals['_COMPONENT']._serialized_start=708
  _globals['_COMPONENT']._serialized_end=1344
  _globals['_COMPONENT_CHOICE']._serialized_start=1180
  _globals['_COMPONENT_CHOICE']._serialized_end=1298
  _globals['_COMPONENT_CHOICE_ENUM']._serialized_start=1190
  _globals['_COMPONENT_CHOICE_ENUM']._serialized_end=1298
  _globals['_LINKPHYSICALBANDWIDTH']._serialized_start=1347
  _globals['_LINKPHYSICALBANDWIDTH']._serialized_end=1751
  _globals['_LINKPHYSICALBANDWIDTH_CHOICE']._serialized_start=1548
  _globals['_LINKPHYSICALBANDWIDTH_CHOICE']._serialized_end=1662
  _globals['_LINKPHYSICALBANDWIDTH_CHOICE_ENUM']._serialized_start=1558
  _globals['_LINKPHYSICALBANDWIDTH_CHOICE_ENUM']._serialized_end=1662
  _globals['_LINKPHYSICALLATENCY']._serialized_start=1754
  _globals['_LINKPHYSICALLATENCY']._serialized_end=1983
  _globals['_LINKPHYSICALLATENCY_CHOICE']._serialized_start=1894
  _globals['_LINKPHYSICALLATENCY_CHOICE']._serialized_end=1951
  _globals['_LINKPHYSICALLATENCY_CHOICE_ENUM']._serialized_start=1904
  _globals['_LINKPHYSICALLATENCY_CHOICE_ENUM']._serialized_end=1951
  _globals['_LINKPHYSICAL']._serialized_start=1985
  _globals['_LINKPHYSICAL']._serialized_end=2103
  _globals['_LINK']._serialized_start=2105
  _globals['_LINK']._serialized_end=2225
  _globals['_DEVICEENDPOINT']._serialized_start=2227
  _globals['_DEVICEENDPOINT']._serialized_end=2313
  _globals['_INFRASTRUCTUREENDPOINT']._serialized_start=2315
  _globals['_INFRASTRUCTUREENDPOINT']._serialized_end=2413
  _globals['_INFRASTRUCTUREEDGE']._serialized_start=2416
  _globals['_INFRASTRUCTUREEDGE']._serialized_end=2711
  _globals['_INFRASTRUCTUREEDGE_SCHEME']._serialized_start=2620
  _globals['_INFRASTRUCTUREEDGE_SCHEME']._serialized_end=2691
  _globals['_INFRASTRUCTUREEDGE_SCHEME_ENUM']._serialized_start=2630
  _globals['_INFRASTRUCTUREEDGE_SCHEME_ENUM']._serialized_end=2691
  _globals['_DEVICEEDGE']._serialized_start=2714
  _globals['_DEVICEEDGE']._serialized_end=2977
  _globals['_DEVICEEDGE_SCHEME']._serialized_start=2620
  _globals['_DEVICEEDGE_SCHEME']._serialized_end=2691
  _globals['_DEVICEEDGE_SCHEME_ENUM']._serialized_start=2630
  _globals['_DEVICEEDGE_SCHEME_ENUM']._serialized_end=2691
  _globals['_INSTANCE']._serialized_start=2980
  _globals['_INSTANCE']._serialized_end=3122
  _globals['_ERROR']._serialized_start=3125
  _globals['_ERROR']._serialized_end=3296
  _globals['_ERROR_KIND']._serialized_start=3217
  _globals['_ERROR_KIND']._serialized_end=3278
  _globals['_ERROR_KIND_ENUM']._serialized_start=3225
  _globals['_ERROR_KIND_ENUM']._serialized_end=3278
  _globals['_WARNING']._serialized_start=3298
  _globals['_WARNING']._serialized_end=3325
  _globals['_GRAPHREQUEST']._serialized_start=3328
  _globals['_GRAPHREQUEST']._serialized_end=3461
  _globals['_GRAPHREQUEST_FORMAT']._serialized_start=3403
  _globals['_GRAPHREQUEST_FORMAT']._serialized_end=3450
  _globals['_GRAPHREQUEST_FORMAT_ENUM']._serialized_start=3413
  _globals['_GRAPHREQUEST_FORMAT_ENUM']._serialized_end=3450
  _globals['_GRAPHCONTENT']._serialized_start=3464
  _globals['_GRAPHCONTENT']._serialized_end=3633
  _globals['_GRAPHCONTENT_CHOICE']._serialized_start=3562
  _globals['_GRAPHCONTENT_CHOICE']._serialized_end=3609
  _globals['_GRAPHCONTENT_CHOICE_ENUM']._serialized_start=3413
  _globals['_GRAPHCONTENT_CHOICE_ENUM']._serialized_end=3450
  _globals['_ANNOTATIONNODE']._serialized_start=3635
  _globals['_ANNOTATIONNODE']._serialized_end=3747
  _globals['_ANNOTATIONEDGE']._serialized_start=3750
  _globals['_ANNOTATIONEDGE']._serialized_end=3886
  _globals['_ANNOTATEREQUEST']._serialized_start=3889
  _globals['_ANNOTATEREQUEST']._serialized_end=4122
  _globals['_ANNOTATEREQUEST_CHOICE']._serialized_start=4056
  _globals['_ANNOTATEREQUEST_CHOICE']._serialized_end=4111
  _globals['_ANNOTATEREQUEST_CHOICE_ENUM']._serialized_start=4066
  _globals['_ANNOTATEREQUEST_CHOICE_ENUM']._serialized_end=4111
  _globals['_NAMEVALUE']._serialized_start=4124
  _globals['_NAMEVALUE']._serialized_end=4193
  _globals['_QUERYRESPONSEITEM']._serialized_start=4195
  _globals['_QUERYRESPONSEITEM']._serialized_end=4281
  _globals['_QUERYSHORTESTPATHITEM']._serialized_start=4283
  _globals['_QUERYSHORTESTPATHITEM']._serialized_end=4349
  _globals['_QUERYRESPONSECONTENT']._serialized_start=4352
  _globals['_QUERYRESPONSECONTENT']._serialized_end=4651
  _globals['_QUERYRESPONSECONTENT_CHOICE']._serialized_start=4562
  _globals['_QUERYRESPONSECONTENT_CHOICE']._serialized_end=4640
  _globals['_QUERYRESPONSECONTENT_CHOICE_ENUM']._serialized_start=4572
  _globals['_QUERYRESPONSECONTENT_CHOICE_ENUM']._serialized_end=4640
  _globals['_QUERYATTRIBUTE']._serialized_start=4654
  _globals['_QUERYATTRIBUTE']._serialized_end=4996
  _globals['_QUERYATTRIBUTE_OPERATOR']._serialized_start=4835
  _globals['_QUERYATTRIBUTE_OPERATOR']._serialized_end=4903
  _globals['_QUERYATTRIBUTE_OPERATOR_ENUM']._serialized_start=4847
  _globals['_QUERYATTRIBUTE_OPERATOR_ENUM']._serialized_end=4903
  _globals['_QUERYATTRIBUTE_LOGIC']._serialized_start=4905
  _globals['_QUERYATTRIBUTE_LOGIC']._serialized_end=4954
  _globals['_QUERYATTRIBUTE_LOGIC_ENUM']._serialized_start=4914
  _globals['_QUERYATTRIBUTE_LOGIC_ENUM']._serialized_end=4954
  _globals['_QUERYNODEID']._serialized_start=4999
  _globals['_QUERYNODEID']._serialized_end=5304
  _globals['_QUERYNODEID_OPERATOR']._serialized_start=4835
  _globals['_QUERYNODEID_OPERATOR']._serialized_end=4903
  _globals['_QUERYNODEID_OPERATOR_ENUM']._serialized_start=4847
  _globals['_QUERYNODEID_OPERATOR_ENUM']._serialized_end=4903
  _globals['_QUERYNODEID_LOGIC']._serialized_start=4905
  _globals['_QUERYNODEID_LOGIC']._serialized_end=4954
  _globals['_QUERYNODEID_LOGIC_ENUM']._serialized_start=4914
  _globals['_QUERYNODEID_LOGIC_ENUM']._serialized_end=4954
  _globals['_QUERYNODEFILTER']._serialized_start=5307
  _globals['_QUERYNODEFILTER']._serialized_end=5595
  _globals['_QUERYNODEFILTER_CHOICE']._serialized_start=5505
  _globals['_QUERYNODEFILTER_CHOICE']._serialized_end=5575
  _globals['_QUERYNODEFILTER_CHOICE_ENUM']._serialized_start=5515
  _globals['_QUERYNODEFILTER_CHOICE_ENUM']._serialized_end=5575
  _globals['_QUERYSHORTESTPATHFILTER']._serialized_start=5597
  _globals['_QUERYSHORTESTPATHFILTER']._serialized_end=5724
  _globals['_QUERYREQUEST']._serialized_start=5727
  _globals['_QUERYREQUEST']._serialized_end=6010
  _globals['_QUERYREQUEST_CHOICE']._serialized_start=5921
  _globals['_QUERYREQUEST_CHOICE']._serialized_end=5999
  _globals['_QUERYREQUEST_CHOICE_ENUM']._serialized_start=5931
  _globals['_QUERYREQUEST_CHOICE_ENUM']._serialized_end=5999
  _globals['_VERSION']._serialized_start=6013
  _globals['_VERSION']._serialized_end=6158
  _globals['_SUCCESS']._serialized_start=6160
  _globals['_SUCCESS']._serialized_end=6207
  _globals['_FAILURE']._serialized_start=6209
  _globals['_FAILURE']._serialized_end=6252
  _globals['_GRAPHRESPONSE']._serialized_start=6254
  _globals['_GRAPHRESPONSE']._serialized_end=6318
  _globals['_QUERYRESPONSE']._serialized_start=6320
  _globals['_QUERYRESPONSE']._serialized_end=6401
  _globals['_DATA']._serialized_start=6403
  _globals['_DATA']._serialized_end=6444
  _globals['_SETGRAPHREQUEST']._serialized_start=6446
  _globals['_SETGRAPHREQUEST']._serialized_end=6515
  _globals['_SETGRAPHRESPONSE']._serialized_start=6517
  _globals['_SETGRAPHRESPONSE']._serialized_end=6573
  _globals['_GETGRAPHREQUEST']._serialized_start=6575
  _globals['_GETGRAPHREQUEST']._serialized_end=6641
  _globals['_GETGRAPHRESPONSE']._serialized_start=6643
  _globals['_GETGRAPHRESPONSE']._serialized_end=6710
  _globals['_QUERYGRAPHREQUEST']._serialized_start=6712
  _globals['_QUERYGRAPHREQUEST']._serialized_end=6780
  _globals['_QUERYGRAPHRESPONSE']._serialized_start=6782
  _globals['_QUERYGRAPHRESPONSE']._serialized_end=6868
  _globals['_ANNOTATEGRAPHREQUEST']._serialized_start=6870
  _globals['_ANNOTATEGRAPHREQUEST']._serialized_end=6947
  _globals['_ANNOTATEGRAPHRESPONSE']._serialized_start=6949
  _globals['_ANNOTATEGRAPHRESPONSE']._serialized_end=7010
  _globals['_GETVERSIONRESPONSE']._serialized_start=7012
  _globals['_GETVERSIONRESPONSE']._serialized_end=7070
  _globals['_OPENAPI']._serialized_start=7073
  _globals['_OPENAPI']._serialized_end=7743
# @@protoc_insertion_point(module_scope)
